VerifyGoogleTokenRequest class

Request body for POST /v1/t/:tenant/google/verify.

Annotations

Constructors

VerifyGoogleTokenRequest({required String idToken, Map<String, String>? context})
const

Properties

context Map<String, String>?
Optional metadata stored on the resulting verify token / auth log.
final
hashCode int
The hash code for this object.
no setteroverride
idToken String
Raw Google ID token from google_sign_in.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override