GetProfileResponse class
Response body for GET /v1/t/:tenant/profile.
The Worker's profile route does not return a message field, so this
model omits it (cf. worker/src/routes/profile.ts).
- Annotations
Constructors
- GetProfileResponse({required String email, required String phone, required bool emailVerified, required bool phoneVerified, required bool smsOptIn})
-
const
-
GetProfileResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- email → String
-
final
- emailVerified → bool
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- phone → String
-
final
- phoneVerified → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- smsOptIn → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override